~~~~~~~~~~~~~~~~~
epub-extract-jpeg
~~~~~~~~~~~~~~~~~

Extract Jpeg files in COMIC EPUB file,


Install
-------

::

  $ pip install epub-extract-jpeg


Requirements
------------

* unzip

* PIL: convert PNG image to Jpeg.
  with option `--no-convert-png` , cancelled.


How to use
----------

::

  $ epub-extract-jpeg xxxx.epub

Create xxx directory, and extract images to there.
